@@ -10,11 +10,13 @@ from .shared import (
     validate_list_model, validate_list_model_config, validate_list_dates_format,
     validate_list_duplicate_values
 )
-from .input import validate_must_include_id
-from .practice import validate_cropResidueManagement, validate_longFallowPeriod
+from .input import validate_must_include_id, validate_input_country
+from .practice import validate_cropResidueManagement, validate_longFallowPeriod, validate_excretaManagement
 from .product import validate_economicValueShare, validate_value as validate_product_value, validate_excreta
 from .data_completeness import validate_dataCompleteness
-from .transformation import validate_previous_transformation, validate_first_transformation
+from .transformation import (
+    validate_previous_transformation, validate_first_transformation, validate_transformation_excretaManagement
+)
 from .property import (
     validate_valueType as validate_properties_valueType, validate_default_value as validate_properties_default_value
 )
@@ -189,7 +191,8 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_list_term_percent(cycle, 'inputs'),
         validate_properties_default_value(cycle, 'inputs'),
         validate_properties_valueType(cycle, 'inputs'),
-        validate_must_include_id(cycle['inputs'])
+        validate_must_include_id(cycle['inputs']),
+        validate_input_country(cycle, 'inputs')
     ] if len(cycle.get('inputs', [])) > 0 else []) + flatten([
         validate_list_dates(cycle, 'products'),
         validate_list_dates_format(cycle, 'products'),
@@ -215,7 +218,8 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_longFallowPeriod(cycle.get('practices')),
         validate_properties_default_value(cycle, 'practices'),
         validate_properties_valueType(cycle, 'practices'),
-        validate_list_duplicate_values(cycle, 'practices', 'term.termType', TermTermType.EXCRETAMANAGEMENT.value)
+        validate_list_duplicate_values(cycle, 'practices', 'term.termType', TermTermType.EXCRETAMANAGEMENT.value),
+        validate_excretaManagement(cycle, cycle.get('practices'))
     ] if len(cycle.get('practices', [])) > 0 else []) + flatten([
         validate_functionalUnit(cycle, site)
     ] if 'functionalUnit' in cycle and site else []) + flatten([
@@ -223,5 +227,6 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_list_dates_format(cycle, 'transformations'),
         validate_list_date_lt_today(cycle, 'transformations', ['startDate', 'endDate']),
         validate_previous_transformation(cycle.get('transformations')),
-        validate_first_transformation(cycle.get('transformations'))
+        validate_first_transformation(cycle.get('transformations')),
+        validate_transformation_excretaManagement(cycle.get('transformations'))
     ] if len(cycle.get('transformations', [])) > 0 in cycle else [])
