@@ -28,3 +28,13 @@ def validate_cropResidueManagement(practices: list):
             'sum': sum
         }
     }
+
+
+def validate_excretaManagement(node: dict, practices: list):
+    has_input = len(_filter_list(node.get('inputs', []), 'term.termType', TermTermType.EXCRETA.value)) > 0
+    has_practice = len(_filter_list(practices, 'term.termType', TermTermType.EXCRETAMANAGEMENT.value)) > 0
+    return not has_practice or has_input or {
+        'level': 'error',
+        'dataPath': '.practices',
+        'message': 'an excreta input is required when using an excretaManagement practice'
+    }
