@@ -254,6 +254,22 @@ def validate_area(node: dict):
         return True
 
 
+MAX_AREA_SIZE = 5000  # in km2
+
+
+def validate_area_size(node: dict):
+    value = node.get('area', 0) / 100
+    return value < MAX_AREA_SIZE or {
+        'level': 'warning',
+        'dataPath': '.area',
+        'message': 'should be lower than max size',
+        'params': {
+            'current': value,
+            'expected': MAX_AREA_SIZE
+        }
+    }
+
+
 N_A_VALUES = [
     '#n/a',
     '#na',
@@ -382,7 +398,8 @@ def _validate_list_model(node: dict, list_key: str, max_delta: float = 0.05):
                     'term': blank_node.get('term', {}),
                     'current': value,
                     'expected': expected_value,
-                    'delta': delta * 100
+                    'delta': delta * 100,
+                    'threshold': max_delta
                 }
             }
         except Exception:
@@ -436,7 +453,8 @@ def _validate_list_model_config(node: dict, list_key: str, conf: dict):
                 'term': term,
                 'current': value,
                 'expected': expected_value,
-                'delta': delta * 100
+                'delta': delta * 100,
+                'threshold': model_conf['delta']
             }
         }
 
