@@ -1,7 +1,11 @@
 import json
 
 from tests.utils import fixtures_path
-from hestia_earth.validation.validators.practice import validate_cropResidueManagement, validate_longFallowPeriod
+from hestia_earth.validation.validators.practice import (
+    validate_cropResidueManagement,
+    validate_longFallowPeriod,
+    validate_excretaManagement
+)
 
 
 def test_validate_cropResidueManagement_valid():
@@ -43,3 +47,22 @@ def test_validate_longFallowPeriod_invalid():
         'dataPath': '.practices[1].value',
         'message': 'longFallowPeriod must be lower than 5 years'
     }
+
+
+def test_validate_excretaManagement_valid():
+    # no practices should be valid
+    assert validate_excretaManagement({}, [])
+
+    with open(f"{fixtures_path}/practice/excretaManagement/valid.json") as f:
+        cycle = json.load(f)
+    assert validate_excretaManagement(cycle, cycle.get('practices')) is True
+
+
+def test_validate_excretaManagement_invalid():
+    with open(f"{fixtures_path}/practice/excretaManagement/invalid.json") as f:
+        cycle = json.load(f)
+    assert validate_excretaManagement(cycle, cycle.get('practices')) == {
+        'level': 'error',
+        'dataPath': '.practices',
+        'message': 'an excreta input is required when using an excretaManagement practice'
+    }
