@@ -8,7 +8,7 @@ from hestia_earth.validation.validators.shared import (
     need_validate_coordinates, validate_list_term_percent, validate_empty_fields, validate_linked_source_privacy,
     validate_list_dates_length, validate_date_lt_today, validate_list_date_lt_today,
     value_difference, is_value_different, validate_list_model, validate_list_model_config,
-    validate_properties_same_length, validate_list_duplicate_values, validate_nodes_duplicates
+    validate_properties_same_length, validate_list_duplicate_values, validate_nodes_duplicates, validate_area_size
 )
 from hestia_earth.validation.validators.cycle import PRODUCTS_MODEL_CONFIG
 
@@ -541,7 +541,8 @@ def test_validate_list_model_invalid():
             },
             'current': 200,
             'expected': 157.100021417863,
-            'delta': 27.310000000000002
+            'delta': 27.310000000000002,
+            'threshold': 0.05
         }
     }
 
@@ -568,7 +569,8 @@ def test_validate_list_model_invalid():
             },
             "current": 5,
             "expected": 0.06419170939,
-            "delta": 7689.17
+            "delta": 7689.17,
+            'threshold': 0.05
         }
     }
 
@@ -607,7 +609,8 @@ def test_validate_list_model_config_invalid():
             },
             'current': 150,
             'expected': 3451.52155,
-            'delta': 95.65
+            'delta': 95.65,
+            'threshold': 0.5
         }
     }
 
@@ -666,3 +669,24 @@ def test_validate_nodes_duplicates_invalid():
         'dataPath': '',
         'message': 'might be a duplicate of the Site with id 2'
     }]
+
+
+def test_validate_area_size_valid():
+    # no area => valid
+    assert validate_area_size({}) is True
+
+    area = 5000
+    assert validate_area_size({'area': area}) is True
+
+
+def test_validate_area_size_warning():
+    area = 520000
+    assert validate_area_size({'area': area}) == {
+        'level': 'warning',
+        'dataPath': '.area',
+        'message': 'should be lower than max size',
+        'params': {
+            'current': 5200,
+            'expected': 5000
+        }
+    }
